@@ -117,6 +117,7 @@ void DirFileSource::save(QTextStream &ts) {
   KstDataSource::save(ts);
 }
 
+#include <kdebug.h>
 
 extern "C" {
 KstDataSource *create_dirfile(const QString& filename, const QString& type) {
@@ -139,6 +140,7 @@ bool understands_dirfile(const QString& filename) {
     return true;
   }
 
+  kdDebug() << "Don't understand.  FrameCount=" << frameCount << " err=" << err << endl;
   return false;
 }
 
