@@ -25,18 +25,18 @@
 #include <qpushbutton.h>
 
 // include files for KDE
+#include <kaccel.h>
+#include <kconfig.h>
+#include <kfiledialog.h>
+#include <kiconloader.h>
+#include <kkeydialog.h>
+#include <klocale.h>
+#include <kmenubar.h>
+#include <kmessagebox.h>
 #include <kprinter.h>
 #include <kstandarddirs.h>
-#include <kiconloader.h>
-#include <kmessagebox.h>
-#include <kfiledialog.h>
-#include <kmenubar.h>
-#include <klocale.h>
-#include <kconfig.h>
-#include <kstdaction.h>
-#include <kaccel.h>
 #include <kstatusbar.h>
-#include <kkeydialog.h>
+#include <kstdaction.h>
 
 #include <iostream>
 
@@ -59,6 +59,8 @@
 #include "kstdatamanager_i.h"
 #include "kstlabeldialog_i.h"
 #include "kstiface_impl.h"
+#include "kstsettingsdlg.h"
+#include "filterlisteditor.h"
 #include "vectorsavedialog.h"
 
 #define KST_STATUSBAR_FRAME 0
@@ -80,6 +82,7 @@ KstApp::KstApp(QWidget *parent, const char* name)
   /* create dialogs */
   plotDialog = new KstPlotDialogI(doc, this);
   dataManager = new KstDataManagerI(doc, this);
+  filterListEditor = new FilterListEditor(this);
   changeFileDialog = new KstChangeFileDialogI(this);
   changeNptsDialog = new KstChangeNptsDialogI(this);
   quickCurvesDialog = new KstQuickCurvesDialogI(this);
@@ -98,9 +101,8 @@ KstApp::KstApp(QWidget *parent, const char* name)
   readOptions();
 
   timer = new QTimer(this);
-  connect(timer, SIGNAL(timeout()),
-           this, SLOT(slotTimer()));
-  timer->start(50,FALSE);
+  connect(timer, SIGNAL(timeout()), this, SLOT(slotTimer()));
+  timer->start(KstSettings::globalSettings()->plotUpdateTimer, false);
 
   connect(doc,  SIGNAL(newFrameMsg(int)),
           this, SLOT(slotUpdateFrameMsg(int)));
@@ -118,6 +120,8 @@ KstApp::KstApp(QWidget *parent, const char* name)
           this,             SLOT(registerDocChange()));
   connect(quickPSDDialog,   SIGNAL(docChanged()),
           this,             SLOT(registerDocChange()));
+  connect(filterListEditor, SIGNAL(docChanged()),
+          this,             SLOT(registerDocChange()));
   connect(graphFileDialog,  SIGNAL(graphFileReq(const QString &,int,int)),
           view,             SLOT(printToGraphicsFile(const QString &,int,int)));
 
@@ -141,6 +145,8 @@ KstApp::KstApp(QWidget *parent, const char* name)
   _dcopIface = new KstIfaceImpl(doc, this);
   view->forceUpdate();
 
+  connect(this, SIGNAL(settingsChanged()), this, SLOT(slotSettingsChanged()));
+
   QTimer::singleShot(0, this, SLOT(updateActions()));
 }
 
@@ -161,32 +167,54 @@ void KstApp::initActions() {
                               this, SLOT(slotFileNewWindow()),
                               actionCollection(),"file_new_window");
 
-  KStdAction::openNew(this, SLOT(slotFileNew()), actionCollection());
-  KStdAction::open(   this, SLOT(slotFileOpen()), actionCollection());
-  KStdAction::save(   this, SLOT(slotFileSave()), actionCollection());
-  KStdAction::saveAs( this, SLOT(slotFileSaveAs()), actionCollection());
-  KStdAction::close(  this, SLOT(slotFileClose()), actionCollection());
-  KStdAction::quit(   this, SLOT(slotFileClose()), actionCollection());
-  KStdAction::keyBindings( this, SLOT( slotConfigureKeys() ), actionCollection() );
+  fileOpenNew = KStdAction::openNew(this, SLOT(slotFileNew()), actionCollection());
+  fileOpenNew->setWhatsThis(i18n("Open Kst plot file."));
+
+  fileSave = KStdAction::save(   this, SLOT(slotFileSave()), actionCollection());
+  fileSave->setWhatsThis(i18n("Save to current Kst plot file."));
+
+  fileSaveAs = KStdAction::saveAs( this, SLOT(slotFileSaveAs()), actionCollection());
+  fileSaveAs->setWhatsThis(i18n("Save to new Kst plot file."));
+
+  fileClose = KStdAction::close(  this, SLOT(slotFileClose()), actionCollection());
+  fileClose->setWhatsThis(i18n("Close Kst."));
+
+  fileQuit = KStdAction::quit(   this, SLOT(slotFileClose()), actionCollection());
+  fileQuit->setWhatsThis(i18n("Quit Kst."));
+
+  fileKeyBindings = KStdAction::keyBindings(this, SLOT(slotConfigureKeys()), actionCollection());
+  fileKeyBindings->setWhatsThis(i18n("Bring up a dialog box\n"
+                                     "to configure shortcuts."));
+
+  filePreferences = KStdAction::preferences(this, SLOT(slotPreferences()), actionCollection());
+  filePreferences->setWhatsThis(i18n("Bring up a dialog box\n"
+                                     "to configure Kst settings."));
+
+  fileCopy = KStdAction::copy(this, SLOT(slotCopy()), actionCollection());
+  fileCopy->setWhatsThis(i18n("Copy cursor position to the clipboard."));
+
   /************/
-  filePrint = KStdAction::print(  this, SLOT(slotFilePrint()),
-				  actionCollection());
-  filePrint ->setToolTip(i18n("Print"));
-  filePrint ->setWhatsThis(i18n("Print current display"));
+  filePrint = KStdAction::print(this, SLOT(slotFilePrint()),
+                                actionCollection());
+  filePrint->setToolTip(i18n("Print"));
+  filePrint->setWhatsThis(i18n("Print current display"));
 
   /************/
   ToolBarAction = KStdAction::showToolbar(this, SLOT(slotViewToolBar()),
                                           actionCollection());
+  ToolBarAction->setWhatsThis(i18n("Toggle Toolbar"));
   connect(ToolBarAction, SIGNAL(activated()), this, SLOT(setSettingsDirty()));
 
   /************/
   StatusBarAction = KStdAction::showStatusbar(this, SLOT(slotViewStatusBar()),
                                               actionCollection());
+  StatusBarAction->setWhatsThis(i18n("Toggle Statusbar"));
   connect(StatusBarAction, SIGNAL(activated()), this, SLOT(setSettingsDirty()));
 
   /************/
   recent = KStdAction::openRecent(this, SLOT(slotFileOpenRecent(const KURL &)),
                            actionCollection());
+  recent->setWhatsThis(i18n("Open a recently used Kst plot."));
 
   /************/
   PauseAction = new KToggleAction(i18n("P&ause"),"player_pause",0,
@@ -199,27 +227,22 @@ void KstApp::initActions() {
                                view, SLOT(toggleTiedZoom()),
                                actionCollection(), "zoomtie_action");
   TiedZoomAction->setToolTip(i18n("Toggle tied zoom"));
-  TiedZoomAction->setWhatsThis( i18n("Apply zoom actions to all plots\n"
+  TiedZoomAction->setWhatsThis(i18n("Apply zoom actions to all plots\n"
                                      "(not just the active one)."));
 
   /************/
   XYZoomAction = new KRadioAction(i18n("XY Mouse &Zoom"), "kst_zoomxy",0,
                                   actionCollection(), "zoomxy_action");
-
   XYZoomAction->setExclusiveGroup("zoom");
-
   XYZoomAction->setToolTip(i18n("XY mouse zoom"));
   XYZoomAction->setWhatsThis(i18n("XY zoom: mouse zooming effects\n"
                                   "both X and Y axis"));
-
   XYZoomAction->setChecked(true);
 
   /************/
   XZoomAction = new KRadioAction(i18n("&X Mouse Zoom"), "kst_zoomx",0,
                                  actionCollection(), "zoomx_action");
-
   XZoomAction->setExclusiveGroup("zoom");
-
   XZoomAction->setToolTip(i18n("X mouse zoom"));
   XZoomAction->setWhatsThis(i18n("X zoom: Mouse zooming effects only the\n"
                                  "X axis (CTRL-mouse also does this)"));
@@ -227,11 +250,8 @@ void KstApp::initActions() {
   /************/
   YZoomAction = new KRadioAction(i18n("&Y Mouse Zoom"), "kst_zoomy",0,
                                   actionCollection(), "zoomy_action");
-
   YZoomAction->setExclusiveGroup("zoom");
-
   YZoomAction->setToolTip(i18n("Y mouse zoom"));
-
   YZoomAction->setWhatsThis(i18n("Y zoom: Mouse zooming effects only the\n"
                                  "Y axis (SHIFT-mouse also does this)"));
 
@@ -240,55 +260,76 @@ void KstApp::initActions() {
                                   actionCollection(), "label_action");
 
   TextAction->setExclusiveGroup("zoom");
-
   TextAction->setToolTip(i18n("Label Editor"));
-
   TextAction->setWhatsThis(i18n("Use the mouse to create and edit labels."));
 
+  /************/
+  FilterDialogAction = new KAction(i18n("Edit &Filters"), 0, 0,
+                                 this, SLOT(showFilterListEditor()),
+                                 actionCollection(), "filterdialog_action");
+  FilterDialogAction->setWhatsThis(i18n("Bring up a dialog box\n"
+                                        "to edit filters."));
+
   /************/
   PlotDialogAction = new KAction(i18n("Edit &Plots"), "kst_editplots", 0,
                                  this, SLOT(showPlotDialog()),
                                  actionCollection(), "plotdialog_action");
+  PlotDialogAction->setWhatsThis(i18n("Bring up a dialog box\n"
+                                      "to edit plot settings."));
 
   /************/
   DataManagerAction = new KAction(i18n("&Data Manager"), "kst_datamanager", 0,
                                   dataManager, SLOT(show_I()),
                                   actionCollection(), "datamanager_action");
+  DataManagerAction->setWhatsThis(i18n("Bring up a dialog box\n"
+                                       "to manage data."));
 
   /************/
-  VectorDialogAction = new KAction(i18n("Edit &Vectors"), "kst_editplots", 0,
+  VectorDialogAction = new KAction(i18n("Edit &Vectors"), 0, 0,
                                  KstVectorDialogI::globalInstance(),
                                  SLOT(show_I()), actionCollection(),
                                  "vectordialog_action");
+  VectorDialogAction->setWhatsThis(i18n("Bring up a dialog box\n"
+                                        "to edit or create vetors."));
 
   /************/
-  CurveDialogAction = new KAction(i18n("Edit &Curves"), "kst_editplots", 0,
+  CurveDialogAction = new KAction(i18n("Edit &Curves"), 0, 0,
                                   KstCurveDialogI::globalInstance(),
                                   SLOT(show_I()), actionCollection(),
                                   "curvedialog_action");
+  CurveDialogAction->setWhatsThis(i18n("Bring up a dialog box\n"
+                                       "to edit or create curves."));
 
   /************/
-  EqDialogAction = new KAction(i18n("Edit &Equations"), "kst_editplots", 0,
+  EqDialogAction = new KAction(i18n("Edit &Equations"), 0, 0,
                                KstEqDialogI::globalInstance(), SLOT(show_I()),
                                actionCollection(), "eqdialog_action");
+  EqDialogAction->setWhatsThis(i18n("Bring up a dialog box\n"
+                                    "to edit or create equations."));
 
   /************/
-  HsDialogAction = new KAction(i18n("Edit &Histograms"), "kst_editplots", 0,
+  HsDialogAction = new KAction(i18n("Edit &Histograms"), 0, 0,
                                KstHsDialogI::globalInstance(),
                                SLOT(show_I()), actionCollection(),
                                "hsdialog_action");
+  HsDialogAction->setWhatsThis(i18n("Bring up a dialog box\n"
+                                    "to edit or create histograms."));
 
   /************/
-  PsdDialogAction = new KAction(i18n("Edit Power &Spectra"), "kst_editplots", 0,
+  PsdDialogAction = new KAction(i18n("Edit Power &Spectra"), 0, 0,
                                 KstPsdDialogI::globalInstance(),
                                 SLOT(show_I()), actionCollection(),
                                 "psddialog_action");
+  PsdDialogAction->setWhatsThis(i18n("Bring up a dialog box\n"
+                                     "to edit or create power spectra."));
 
   /************/
-  PluginDialogAction = new KAction(i18n("Edit Plugins"), 0,0,
+  PluginDialogAction = new KAction(i18n("Edit Plugins"), 0, 0,
                                    KstPluginDialogI::globalInstance(),
                                    SLOT(show_I()), actionCollection(),
                                    "plugindialog_action");
+  PluginDialogAction->setWhatsThis(i18n("Bring up a dialog box\n"
+                                        "to use plugins."));
 
   /************/
   ChangeFileDialogAction = new KAction(i18n("Change Data &File"),
@@ -383,13 +424,21 @@ void KstApp::initActions() {
   PluginManagerAction = new KAction(i18n("&Plugins"), 0, 0,
                                  this, SLOT(showPluginManager()),
                                  actionCollection(), "pluginmanager_action");
+  PluginManagerAction->setWhatsThis(i18n("Bring up a dialog box\n"
+                                           "to manage plugins."));
 
-  DataMode = new KToggleAction(i18n("DataMode"), 0, 0,
+
+  /************/
+  DataMode = new KToggleAction(i18n("Data Mode"), "kst_datamode", 0,
                                  this, SLOT(toggleDataMode()),
                                  actionCollection(), "datamode_action");
+  DataMode->setWhatsThis(i18n("Toggle between cursor mode and data mode."));
 
+  /************/
   _reloadAction = new KAction(i18n("Reload"), "reload", Key_F5, this, SLOT(reload()),
                               actionCollection(), "reload");
+  _reloadAction->setWhatsThis(i18n("Reload the data from file."));
+
   createGUI();
 }
 
@@ -455,6 +504,7 @@ void KstApp::forcedUpdate() {
 
 void KstApp::initView() {
   view = new KstView(this);
+  connect(this, SIGNAL(settingsChanged()), view, SLOT(update()));
   setCentralWidget(view);
   setCaption(doc->getTitle());
 }
@@ -723,14 +773,13 @@ void KstApp::slotTimer() {
   }
 
   if (PauseAction->isChecked()) { // Paused: don't update
-    timer->start(200);
     return;
   }
 
   // pause during mouse zooming
   KstMouseModeType M = view->MouseInfo->getMode();
   if (M == XY_ZOOMBOX || M == Y_ZOOMBOX || M == X_ZOOMBOX) {
-    timer->start(200);
+    timer->start(KstSettings::globalSettings()->plotUpdateTimer, false);
     return;
   }
 
@@ -739,8 +788,7 @@ void KstApp::slotTimer() {
   if (U == KstObject::UPDATE) {
     view->update();
   }
-
-  timer->start(doc->delay());
+  timer->start(KstSettings::globalSettings()->plotUpdateTimer, false);
 }
 
 void KstApp::showPlotDialog() {
@@ -771,6 +819,10 @@ void KstApp::showGraphFileDialog() {
   graphFileDialog->showGraphFileDialog();
 }
 
+void KstApp::showFilterListEditor() {
+  filterListEditor->show();
+}
+
 void KstApp::samplesUp() {
   setPaused(false);
   doc->samplesUp();
@@ -800,6 +852,7 @@ void KstApp::updateDialogs() {
   quickCurvesDialog->update();
   quickPSDDialog->update();
   dataManager->update();
+  filterListEditor->update();
   vectorSaveDialog->init();
   view->update();
 }
@@ -824,8 +877,7 @@ void KstApp::registerDocChange() {
 
 
 void KstApp::reload() {
-  for (KstVectorList::Iterator i = KST::vectorList.begin(); i != KST::vectorList
-      .end(); ++i) {
+  for (KstVectorList::Iterator i = KST::vectorList.begin(); i != KST::vectorList.end(); ++i) {
     KstRVector *r = dynamic_cast<KstRVector*>((*i).data());
     if (r) {
       r->reload();
@@ -834,5 +886,23 @@ void KstApp::reload() {
 }
 
 
+void KstApp::slotPreferences() {
+  KstSettingsDlg *ksd = new KstSettingsDlg(this, "Kst Settings Dialog");
+  connect(ksd, SIGNAL(settingsChanged()), this, SIGNAL(settingsChanged()));
+  ksd->exec();
+  delete ksd;
+}
+
+
+void KstApp::slotSettingsChanged() {
+  timer->stop();
+  timer->start(KstSettings::globalSettings()->plotUpdateTimer, false);
+}
+
+
+void KstApp::slotCopy() {
+  view->copy();
+}
+
 #include "kst.moc"
 // vim: ts=2 sw=2 et
