@@ -106,7 +106,10 @@ void KstCurveDialogI::update(int new_index) {
       }
       Select->setCurrentText(save);
       Select->blockSignals(false);
-      return;
+      //
+      // do not return here as the signal may indicate that we have both a new
+      //  curve and a new vector. So far we have dealt only with the new curve.
+      //
     }
   }
 
