@@ -20,6 +20,7 @@
 
 #include "kstvector.h"
 #include "kstscalar.h"
+#include "kstfilter.h"
 #include "kstdataobject.h"
 #include "kstdatasource.h"
 
@@ -38,6 +39,9 @@ namespace KST {
   /** The list of data objects which are in use */
   extern KstDataObjectList dataObjectList;
 
+  /** The list of filter sets that are defined */
+  extern KstFilterSetList filterSetList;
+
   /** check that a tag has not been used by any other tags */
   extern bool dataTagNameNotUnique(const QString &tag, bool warn = true);
   extern bool vectorTagNameNotUnique(const QString &tag, bool warn = true);
