@@ -39,25 +39,27 @@
 #include <qlistbox.h>
 
 // include files for KDE
+#include <kapplication.h>
+#include <kcolordialog.h>
 #include <kdebug.h>
-#include <kurl.h>
+#include <kfiledialog.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <kfiledialog.h>
-#include <kcolordialog.h>
+#include <kprogress.h>
 #include <ksavefile.h>
-#include <kapplication.h>
+#include <kurl.h>
 
 // application specific includes
-#include "kstdoc.h"
-#include "kstpoint.h"
-#include "kstplugin.h"
 #include "kst.h"
-#include "kstvcurve.h"
-#include "kstpsdcurve.h"
-#include "kstequationcurve.h"
-#include "ksthistogram.h"
 #include "kstdatacollection.h"
+#include "kstdoc.h"
+#include "kstequationcurve.h"
+#include "kstfilteredvector.h"
+#include "ksthistogram.h"
+#include "kstplugin.h"
+#include "kstpoint.h"
+#include "kstpsdcurve.h"
+#include "kstvcurve.h"
 
 static bool backupFile(const QString& qFilename, const QString& backupDir = QString::null, const QString& backupExtension = "~");
 
@@ -73,6 +75,7 @@ KstDoc::~KstDoc() {
     // guaranteed by any means and KstDoc::vectorList is static and has a
     // pointer to KstDoc::scalarList, also static, which gets used during
     // vector destruction.
+    KST::filterSetList.clear();
     KST::plotList.clear();
     KST::vectorList.clear();
     KST::scalarList.clear();
@@ -213,6 +216,11 @@ bool KstDoc::openDocument(const KURL &url, const QString &o_file,
       } else if (e.tagName() == "vector") {
         vector = new KstRVector(e, o_file, o_n, o_f, o_s, o_ave);
         // Vectors are automatically added to the global list.
+      } else if (e.tagName() == "filterset") {
+        KST::filterSetList.append(new KstFilterSet(e));
+      } else if (e.tagName() == "filteredvector") {
+        new KstFilteredVector(e);
+        // Vectors are automatically added to the global list.
       } else if (e.tagName() == "plugin") {
         KST::dataObjectList.append(new KstPlugin(e));
       } else if (e.tagName() == "curve") {
@@ -263,6 +271,7 @@ bool KstDoc::saveDocument(const QString &filename) {
 
   QTextStream ts(&f);
 
+  ts << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>" << endl;
   ts << "<kstdoc>" << endl;
   // save window geometry for this kst file
   ts << " <windowsize>" << endl;
@@ -296,6 +305,20 @@ bool KstDoc::saveDocument(const QString &filename) {
     (*it)->save(ts);
   }
 
+  // save filters
+  for (KstFilterSetList::Iterator it = KST::filterSetList.begin(); it != KST::filterSetList.end(); ++it) {
+    ts << " <filterset>" << endl;
+    (*it)->save(ts);
+    ts << " </filterset>" << endl;
+  }
+
+  KstFilteredVectorList fvl = kstObjectSubList<KstVector,KstFilteredVector>(KST::vectorList);
+  for (KstFilteredVectorList::Iterator it = fvl.begin(); it != fvl.end(); ++it) {
+    ts << " <filteredvector>" << endl;
+    (*it)->save(ts);
+    ts << " </filteredvector>" << endl;
+  }
+
   // save plots
   for (i = 0; i < (int)KST::plotList.count(); i++) {
     ts << " <plot>" << endl;
@@ -395,6 +418,26 @@ KstObject::UpdateType KstDoc::update(bool force) {
     }
   }
 
+  /* update all vectors  -  brute force */
+  for (KstVectorList::Iterator it = KST::vectorList.begin(); it != KST::vectorList.end(); ++it) {
+    if (dynamic_cast<KstRVector*>((*it).data())) {
+      continue;
+    }
+
+    tU = (*it)->update(UpdateCounter);
+    if (tU != KstObject::NO_CHANGE) {
+      kapp->processEvents();
+      if (stopping) {
+        return KstObject::NO_CHANGE;
+      }
+      if (tU == KstObject::READ) {
+        U = KstObject::READ;
+      } else if (U == KstObject::NO_CHANGE) {
+        U = KstObject::UPDATE;
+      }
+    }
+  }
+
   // update curves next
   if ((U == KstObject::UPDATE) || force) {
     for (KstDataObjectList::Iterator it = KST::dataObjectList.begin(); it != KST::dataObjectList.end(); ++it) {
@@ -538,6 +581,20 @@ RemoveStatus KstDoc::removeDataObject(const QString &tag) {
 
 void KstDoc::purge() {
   bool modified = false;
+  KstRVectorList rvl = kstObjectSubList<KstVector,KstRVector>(KST::vectorList);
+  KstFilteredVectorList fvl = kstObjectSubList<KstVector,KstFilteredVector>(KST::vectorList);
+
+  int cnt = rvl.count() + fvl.count() + KST::dataObjectList.count();
+  int prg = 0;
+
+  KProgressDialog *dlg = new KProgressDialog((QWidget*)dynamic_cast<KstApp*>(parent())->viewObject(), "Progress Dialog");
+
+  dlg->setAllowCancel(false);
+  dlg->progressBar()->setTotalSteps(cnt);
+  dlg->progressBar()->setProgress(0);
+  dlg->setLabel(i18n("Purging unused objects..."));
+  dlg->show();
+
   // ASSUMPTION: this only gets called from the data manager!
   for (KstDataObjectList::Iterator it = KST::dataObjectList.begin(); it != KST::dataObjectList.end(); ++it) {
     //kdDebug() << "OBJECT: " << (*it)->tagName() << " USAGE: " << (*it)->getUsage() << endl;
@@ -548,9 +605,10 @@ void KstDoc::purge() {
       KST::dataObjectList.remove(byebye);
       modified = true;
     }
+    dlg->progressBar()->setProgress(++prg);
+    kapp->processEvents();
   }
 
-  KstRVectorList rvl = kstObjectSubList<KstVector,KstRVector>(KST::vectorList);
   for (KstRVectorList::Iterator it = rvl.begin(); it != rvl.end(); ++it) {
     //kdDebug() << "VECTOR: " << (*it)->tagName() << " USAGE: " << (*it)->getUsage() << endl;
     if ((*it)->getUsage() == 1) {
@@ -558,11 +616,29 @@ void KstDoc::purge() {
       KST::vectorList.remove((*it).data());
       modified = true;
     }
+    dlg->progressBar()->setProgress(++prg);
+    kapp->processEvents();
   }
 
   rvl.clear();
+
+  for (KstFilteredVectorList::Iterator it = fvl.begin(); it != fvl.end(); ++it) {
+    //kdDebug() << "VECTOR: " << (*it)->tagName() << " USAGE: " << (*it)->getUsage() << endl;
+    if ((*it)->getUsage() == 1) {
+      //kdDebug() << "    -> REMOVED" << endl;
+      KST::vectorList.remove((*it).data());
+      modified = true;
+    }
+    dlg->progressBar()->setProgress(++prg);
+    kapp->processEvents();
+  }
+
+  fvl.clear();
+
   setModified(modified);
   updateDialogs();
+
+  delete dlg;
 }
 
 static int write_all(int fd, const char *buf, size_t len) {
