@@ -206,8 +206,10 @@ KstObject::UpdateType KstEquationCurve::update(int update_counter) {
 
 // FIXME: Optimize me, especially map lookups.
 void KstEquationCurve::getPoint(int i, double &x, double &y) {
-  x = _inputVectors[XVECTOR]->interpolate(i, NS);
-  y = _outputVectors[OUTVECTOR]->value()[i];
+  KstVectorPtr xv = _inputVectors[XVECTOR];
+  KstVectorPtr yv = _outputVectors[OUTVECTOR];
+  x = xv->interpolate(i, NS);
+  y = yv->value()[i];
 }
 
 void KstEquationCurve::save(QTextStream &ts) {
@@ -351,9 +353,10 @@ void KstEquationCurve::preProcess() {
       ts[i_t-i-1] = '\0';
       replaced = false;
       for (i_v = 0; i_v < KST::vectorList.count(); i_v++) {
+        // FIXME: "- 'a'" probably only allows 26 vectors in an equation
         if (KST::vectorList[i_v]->tagName() == ts) {
           String[j++] = 'V';
-          String[j++] = '0' + i_v;
+          String[j++] = 'a' + i_v;
           VectorsUsed.append(KST::vectorList[i_v]);
           i_v = KST::vectorList.count();
           replaced = true;
@@ -395,7 +398,7 @@ bool KstEquationCurve::FillRPNQ() {
   bool Ok=true, Error=false;
 
   int i=0,j;
-  char Tmp[160]="",Tmp2[160],Tmp1[160],Tmp3[6];
+  char Tmp[300]="",Tmp2[300],Tmp1[300],Tmp3[7];
 
   vstack.reset();
   opstack.reset();
@@ -414,14 +417,12 @@ bool KstEquationCurve::FillRPNQ() {
 	  vstack.Pop(Tmp2);
 	  vstack.Pop(Tmp1);
 	  opstack.Pop(Tmp3);
-          // FIXME: buffer overflow
-	  sprintf(Tmp,"%s;%s;%s;",Tmp1,Tmp2,Tmp3);
+	  sprintf(Tmp,"%.140s;%.140s;%.6s;",Tmp1,Tmp2,Tmp3);
 	  vstack.LPush(Tmp);
 	} else {
 	  vstack.Pop(Tmp1);
 	  opstack.Pop(Tmp2);
-          // FIXME: buffer overflow
-	  sprintf(Tmp,"%s;%s;",Tmp1,Tmp2);
+	  sprintf(Tmp,"%.140s;%.6s;",Tmp1,Tmp2);
 	  vstack.LPush(Tmp);
 	}
       }
@@ -439,14 +440,12 @@ bool KstEquationCurve::FillRPNQ() {
 	    vstack.Pop(Tmp2);
 	    vstack.Pop(Tmp1);
 	    opstack.Pop(Tmp3);
-          // FIXME: buffer overflow
-	    sprintf(Tmp,"%s;%s;%s;",Tmp1,Tmp2,Tmp3);
+	    sprintf(Tmp,"%.140s;%.140s;%.6s;",Tmp1,Tmp2,Tmp3);
 	    vstack.LPush(Tmp);
 	  } else {
 	    vstack.Pop(Tmp1);
 	    opstack.Pop(Tmp2);
-          // FIXME: buffer overflow
-	    sprintf(Tmp,"%s;%s;",Tmp1,Tmp2);
+	    sprintf(Tmp,"%.140s;%.6s;",Tmp1,Tmp2);
 	    vstack.LPush(Tmp);
 	  }
 	  opstack.cPeek(Tmp);
@@ -472,18 +471,20 @@ bool KstEquationCurve::FillRPNQ() {
       vstack.Pop(Tmp2);
       vstack.Pop(Tmp1);
       opstack.Pop(Tmp3);
-      // FIXME: buffer overflow
-      sprintf(Tmp,"%s;%s;%s;",Tmp1,Tmp2,Tmp3);
+      sprintf(Tmp,"%.140s;%.140s;%.6s;",Tmp1,Tmp2,Tmp3);
       vstack.LPush(Tmp);
     } else {
       vstack.Pop(Tmp1);
       opstack.Pop(Tmp2);
-      // FIXME: buffer overflow
-      sprintf(Tmp,"%s;%s;",Tmp1,Tmp2);
+      sprintf(Tmp,"%.140s;%.6s;",Tmp1,Tmp2);
       vstack.LPush(Tmp);
     }
   }
   vstack.Pop(Tmp);
+
+  // was the equation too long?
+  if (strlen(Tmp)>140) Error = true;
+
   for (i=0;Tmp[i]!='\0';) {
     for (j=0;Tmp[i+j]!=';'&& Tmp[i+j]!='\0';j++) {
       Tmp1[j]=Tmp[j+i];
@@ -604,7 +605,7 @@ bool KstEquationCurve::FillY(bool force) {
       } else if (String[0]=='x') {
 	numstack.Push(X);
       } else if (String[0]=='V') { // a vector
-        r = String[1] - '0';
+        r = String[1] - 'a';
         if (r < KST::vectorList.count()) {
           numstack.Push(KST::vectorList[r]->interpolate(i, NS));
         } else {
