@@ -332,3 +332,32 @@ void KstHistogram::_showDialog() {
   KstHsDialogI::globalInstance()->show_I(tagName());
 }
 
+void KstHistogram::AutoBin(KstVectorPtr V,
+                           int *n, double *max, double *min) {
+  double m;
+
+  *max = V->max();
+  *min = V->min();
+  *n = V->sampleCount();
+
+  if (*max < *min) {
+    m = *max;
+    *max = *min;
+    *min = m;
+  }
+  if (*max == *min) {
+    *max += 1;
+    *min -= 1;
+  }
+
+  // we can do a better job auto-ranging using the tick rules from plot...
+  // this has not been done yet, you will notice...
+  *n /= 50;
+  if (*n < 6) *n = 6;
+  if (*n > 60) *n = 60;
+
+  m = (*max - *min)/(100.0*double(*n));
+  *max += m;
+  *min -= m;
+
+}
