@@ -34,6 +34,7 @@ typedef enum {CxBy, CxTy, CxCy, LxBy, LxTy,
 
 class KstLabel {
 public:
+  KstLabel( );
   KstLabel(const QString &in_text, KstJustifyType in_j = CxBy,
            float in_rotation = 0.0, float in_X=0.0,
            float in_Y=0.0, bool is_sample = false);
@@ -42,6 +43,7 @@ public:
   void setText(const QString &text);
   void setRotation(float new_rotation);
   void setRelPosition(float new_x, float new_y);
+  void offsetRelPosition(float offset_x, float offset_y);
   void setJustification(KstJustifyType Justify);
 
   KstJustifyType justification() const {return Justify;}
@@ -54,15 +56,16 @@ public:
   float rotation() const {return Rotation;}
 
   /** draw the label with painter at px, py */
-  void draw(QPainter &p, int px, int py, bool doDraw=true);
+  void draw(QPainter &p, int px, int py, bool bJustify=true, bool doDraw=true);
+
+  /** Interpret special characters, default = true */
+  void setInterpreted(bool interpreted) { _interpret = interpreted; }
 
   void setSize(int size);
   void setFontName(const QString &fontName);
   QString fontName();
   int size();
 
-  void move(float x, float y) { _x = x; _y = y; }
-
   void save(QTextStream &ts);
   void read(QDomElement &e);
 
@@ -73,12 +76,14 @@ public:
   inline double x() const {return _x;}
   inline double y() const {return _y;}
 
-  QRect extents;
-
+  QRegion extents;
+  int     v_offset;
+  
 private:
   /** Computes the font size, given the size of the painter, and Size */
   int fontSize(QPainter &p);
 
+  bool _interpret;
   float Rotation;
   QString Text;
   KstJustifyType Justify;
