@@ -1,4 +1,5 @@
-/**************************************************************************              kstplotdialog_i.cpp - plot dialog: inherits designer dialog
+/**************************************************************************
+              kstplotdialog_i.cpp - plot dialog: inherits designer dialog
                              -------------------
     begin                :  2000
     copyright            : (C) 2000-2002 by Barth Netterfield
@@ -26,9 +27,12 @@
 #include <qstring.h>
 #include <klistbox.h>
 #include <qspinbox.h>
+#include <qmessagebox.h>
+#include <qtabwidget.h>
 
 // include files for KDE
 #include <klocale.h>
+#include <kcolorbutton.h>
 #include <kdualcolorbutton.h>
 #include <kmessagebox.h>
 #include <kfontcombo.h>
@@ -36,8 +40,41 @@
 #include <qpushbutton.h>
 #include <qradiobutton.h>
 
+#include "kstlegend.h"
 #include "kstdatacollection.h"
 #include "kstplotdialog_i.h"
+#include "kstsettings.h"
+
+struct LegendLayout {
+  QString Label;
+  KstLegendLayoutType	type;
+};
+
+struct LegendAlignment {
+  QString Label;
+  KstLegendAlignmentType	type;
+};
+
+const LegendAlignment LegendAlignments[] = {
+  { i18n("Right"), AlignmentRight },
+  { i18n("Center"), AlignmentCentre },
+  { i18n("Left"), AlignmentLeft }
+};
+
+const LegendLayout LegendLayouts[] = {
+  { i18n("Top left"), LeftTop },
+  { i18n("Top center"), CentreTop },
+  { i18n("Top right"), RightTop },
+  { i18n("Middle left"), LeftCentre },
+  { i18n("Middle center"), CentreCentre },
+  { i18n("Middle right"), RightCentre },
+  { i18n("Bottom left"), LeftBottom },
+  { i18n("Bottom center"), CentreBottom },
+  { i18n("Bottom right"), RightBottom }
+};
+
+const int iNumLegendLayouts = sizeof( LegendLayouts ) / sizeof( LegendLayout );
+const int iNumLegendAlignments = sizeof( LegendAlignments ) / sizeof( LegendAlignment );
 
 /*
  *  Constructs a KstPlotDialogI which is a child of 'parent', with the
@@ -49,74 +86,109 @@
 KstPlotDialogI::KstPlotDialogI(KstDoc *in_doc, QWidget* parent,
                                const char* name, bool modal, WFlags fl)
 : KstPlotDialog(parent, name, modal, fl ) {
+  QString str;
 
-    doc = in_doc;
-    setScalarDestTopLabel();
+  doc = in_doc;
+  setScalarDestTopLabel();
 
-    connect(Select, SIGNAL(activated(int)), this, SLOT(update(int)));
-    connect(New, SIGNAL(clicked()), this, SLOT(new_I()));
-    connect(Edit, SIGNAL(clicked()), this, SLOT(edit_I()));
-    connect(Delete, SIGNAL(clicked()), this, SLOT(delete_I()));
+  connect(Select, SIGNAL(activated(int)), this, SLOT(update(int)));
+  connect(TabWidget, SIGNAL(currentChanged(QWidget*)), this, SLOT(newTab()));
+  connect(New, SIGNAL(clicked()), this, SLOT(new_I()));
+  connect(Edit, SIGNAL(clicked()), this, SLOT(edit_I()));
+  connect(Delete, SIGNAL(clicked()), this, SLOT(delete_I()));
 
-    connect(DisplayedCurveList, SIGNAL(selectionChanged(QListBoxItem*)),
-            this, SLOT(updateButtons()));
-    connect(AvailableCurveList, SIGNAL(selectionChanged(QListBoxItem*)),
-            this, SLOT(updateButtons()));
+  connect(DisplayedCurveList, SIGNAL(selectionChanged(QListBoxItem*)),
+          this, SLOT(updateButtons()));
+  connect(AvailableCurveList, SIGNAL(selectionChanged(QListBoxItem*)),
+          this, SLOT(updateButtons()));
 
-    /* adding/removing curves */
-    connect(CurveUnplot, SIGNAL(clicked()),
-            this, SLOT(removeDisplayedCurve()));
-    connect(DisplayedCurveList, SIGNAL(executed(QListBoxItem*)),
-            this, SLOT(removeDisplayedCurve()));
-    connect(CurvePlot, SIGNAL(clicked()),
-            this, SLOT(addDisplayedCurve()));
-    connect(AvailableCurveList, SIGNAL(executed(QListBoxItem*)),
-            this, SLOT(addDisplayedCurve()));
+  /* adding/removing curves */
+  connect(CurveUnplot, SIGNAL(clicked()),
+          this, SLOT(removeDisplayedCurve()));
+  connect(DisplayedCurveList, SIGNAL(executed(QListBoxItem*)),
+          this, SLOT(removeDisplayedCurve()));
+  connect(CurvePlot, SIGNAL(clicked()),
+          this, SLOT(addDisplayedCurve()));
+  connect(AvailableCurveList, SIGNAL(executed(QListBoxItem*)),
+          this, SLOT(addDisplayedCurve()));
 
-    /* labels */
-    connect(TopLabelText, SIGNAL(textChanged(const QString &)),
-            this, SLOT(updateSampTopLabel()));
-    connect(XAxisText, SIGNAL(textChanged(const QString &)),
-            this, SLOT(updateSampXLabel()));
-    connect(YAxisText, SIGNAL(textChanged(const QString &)),
-            this, SLOT(updateSampYLabel()));
-    connect(TopLabelFontSize, SIGNAL(valueChanged(int)),
-            this, SLOT(updateSampTopLabel()));
-    connect(XLabelFontSize, SIGNAL(valueChanged(int)),
-            this, SLOT(updateSampXLabel()));
-    connect(YLabelFontSize, SIGNAL(valueChanged(int)),
-            this, SLOT(updateSampYLabel()));
-    connect(NumberFontSize, SIGNAL(valueChanged(int)),
-            this, SLOT(updateSampNumLabel()));
-    connect(FontComboBox, SIGNAL(activated(int)),
-            this, SLOT(updateLabels()));
-    connect(FontComboBox, SIGNAL(highlighted(int)),
-            this, SLOT(updateLabels()));
-    connect(FontComboBox, SIGNAL(textChanged(const QString &)),
-            this, SLOT(updateLabels()));
-    connect(AutoLabel, SIGNAL(clicked()),
-            this, SLOT(applyAutoLabels()));
+  /* labels */
+  connect(TopLabelText, SIGNAL(textChanged(const QString &)),
+          this, SLOT(updateSampTopLabel()));
+  connect(XAxisText, SIGNAL(textChanged(const QString &)),
+          this, SLOT(updateSampXLabel()));
+  connect(YAxisText, SIGNAL(textChanged(const QString &)),
+          this, SLOT(updateSampYLabel()));
+  connect(TopLabelFontSize, SIGNAL(valueChanged(int)),
+          this, SLOT(updateSampTopLabel()));
+  connect(XLabelFontSize, SIGNAL(valueChanged(int)),
+          this, SLOT(updateSampXLabel()));
+  connect(YLabelFontSize, SIGNAL(valueChanged(int)),
+          this, SLOT(updateSampYLabel()));
+  connect(NumberFontSize, SIGNAL(valueChanged(int)),
+          this, SLOT(updateSampNumLabel()));
+  connect(FontComboBox, SIGNAL(activated(int)),
+          this, SLOT(updateLabels()));
+  connect(FontComboBox, SIGNAL(highlighted(int)),
+          this, SLOT(updateLabels()));
+  connect(FontComboBox, SIGNAL(textChanged(const QString &)),
+          this, SLOT(updateLabels()));
+  connect(AutoLabel, SIGNAL(clicked()),
+          this, SLOT(applyAutoLabels()));
 
+  connect(ScalarList, SIGNAL(activated(int)),
+          this, SLOT(insertCurrentScalar()));
 
-    connect(ScalarList, SIGNAL(activated(int)),
-            this, SLOT(insertCurrentScalar()));
+  connect(YAxisText, SIGNAL(selectionChanged()),
+          this, SLOT(setScalarDestYLabel()));
+  connect(YAxisText, SIGNAL(textChanged(const QString &)),
+          this, SLOT(setScalarDestYLabel()));
+  connect(XAxisText, SIGNAL(selectionChanged()),
+          this, SLOT(setScalarDestXLabel()));
+  connect(XAxisText, SIGNAL(textChanged(const QString &)),
+          this, SLOT(setScalarDestXLabel()));
+  connect(TopLabelText, SIGNAL(selectionChanged()),
+          this, SLOT(setScalarDestTopLabel()));
+  connect(TopLabelText, SIGNAL(textChanged(const QString &)),
+          this, SLOT(setScalarDestTopLabel()));
 
-    connect(YAxisText, SIGNAL(selectionChanged()),
-            this, SLOT(setScalarDestYLabel()));
-    connect(YAxisText, SIGNAL(textChanged(const QString &)),
-            this, SLOT(setScalarDestYLabel()));
-    connect(XAxisText, SIGNAL(selectionChanged()),
-            this, SLOT(setScalarDestXLabel()));
-    connect(XAxisText, SIGNAL(textChanged(const QString &)),
-            this, SLOT(setScalarDestXLabel()));
-    connect(TopLabelText, SIGNAL(selectionChanged()),
-            this, SLOT(setScalarDestTopLabel()));
-    connect(TopLabelText, SIGNAL(textChanged(const QString &)),
-            this, SLOT(setScalarDestTopLabel()));
+  SampleLabel = new KstLabel("\0", CxCy, 0.0, 0.0, 0.0, true);
+  QFontDatabase qfd;
+  FontComboBox->setFonts(qfd.families());
 
-    SampleLabel = new KstLabel("\0", CxCy, 0.0, 0.0, 0.0, true);
-    QFontDatabase qfd;
-    FontComboBox->setFonts(qfd.families());
+  /* Legend */
+  connect(LegendFontSize, SIGNAL(valueChanged(int)),
+          this, SLOT(updateSampLegendLabel()));
+  connect(LegendFontComboBox, SIGNAL(textChanged(const QString &)),
+          this, SLOT(updateSampLegendLabel()));
+  connect(LegendFontComboBox, SIGNAL(activated(int)),
+          this, SLOT(updateSampLegendLabel()));
+  connect(LegendFontComboBox, SIGNAL(highlighted(int)),
+          this, SLOT(updateSampLegendLabel()));
+//   connect(LegendFontComboBox, SIGNAL(textChanged(const QString &)),
+//           this, SLOT(updateSampLegendLabels()));
+  connect(legendColors, SIGNAL(fgChanged(const QColor &)),
+          this, SLOT(updateSampLegendLabel()));
+  connect(legendColors, SIGNAL(bgChanged(const QColor &)),
+          this, SLOT(updateSampLegendLabel()));
+  connect(legendInFront, SIGNAL(clicked()),
+          this, SLOT(updateSampLegendLabel()));
+
+  LegendFontComboBox->setFonts(qfd.families());
+
+  LegendPosition->hide();
+  LegendPositionLabel->hide();
+  LegendPosition->setEditable( false );
+  for( int i=0; i<iNumLegendLayouts; i++ ) {
+    str = LegendLayouts[i].Label;
+    LegendPosition->insertItem( str );
+  }
+
+  LegendAlignment->setEditable( false );
+  for( int i=0; i<iNumLegendAlignments; i++ ) {
+    str = LegendAlignments[i].Label;
+    LegendAlignment->insertItem( str );
+  }
 }
 
 KstPlotDialogI::~KstPlotDialogI() {
@@ -130,6 +202,11 @@ void KstPlotDialogI::show_I() {
   update();
 }
 
+void KstPlotDialogI::newTab( ) {
+    updateLabels();
+    updateSampLegendLabel();
+}
+
 void KstPlotDialogI::update(int new_index) {
   int index;
   int i_plot;
@@ -183,8 +260,8 @@ void KstPlotDialogI::update(int new_index) {
   if (i_plot >= 0) {
     plot = KST::plotList.at(i_plot);
 
-    Colors->setForeground(plot->foregroundColor());
-    Colors->setBackground(plot->backgroundColor());
+//     Colors->setForeground(plot->foregroundColor());
+//     Colors->setBackground(plot->backgroundColor());
 
     /* insert the current plot name in the plot name edit box */
     Name->setText(plot->tagName());
@@ -252,9 +329,18 @@ void KstPlotDialogI::update(int new_index) {
 
     FontComboBox->setCurrentFont(plot->TopLabel->fontName());
 
-    updateSampXLabel();
-    updateSampYLabel();
-    updateSampNumLabel();
+    updateLabels();
+
+    /* initialize all the legend settings for the current plot */
+    LegendFontComboBox->setCurrentFont(plot->Legend->fontName());
+    LegendFontSize->setValue(plot->Legend->size());
+    ShowLegend->setChecked(plot->Legend->getShow());
+
+    legendInFront->setChecked(plot->Legend->getFront());
+    legendColors->setForeground(plot->Legend->getColorForeground());
+    legendColors->setBackground(plot->Legend->getColorBackground());
+
+    updateSampLegendLabel();
   } else {
     for (KstBaseCurveList::iterator it = curves.begin(); it != curves.end(); it++) {
       AvailableCurveList->insertItem((*it)->tagName());
@@ -263,13 +349,17 @@ void KstPlotDialogI::update(int new_index) {
 
   PlotCols->setValue(KST::plotList.getPlotCols());
 
-  UpdateDelay->setValue(doc->delay());
+  //UpdateDelay->setValue(doc->delay());
 
   updateButtons();
 }
 
 void KstPlotDialogI::applyLabels(KstPlot *plot) {
-  int i_plot, plot_min, plot_max;
+  QString strAlignment;
+  QString strLayout;
+  KstLegendLayoutType layout = LeftTop;
+  KstLegendAlignmentType alignment = AlignmentRight;
+  int i, i_plot, plot_min, plot_max;
 
   plot->XLabel->setText((XAxisText)->text());
   plot->YLabel->setText((YAxisText)->text());
@@ -303,6 +393,43 @@ void KstPlotDialogI::applyLabels(KstPlot *plot) {
     plot->TickLabel->setFontName(FontComboBox->currentText());
     plot->TickLabel->setSize(NumberFontSize->value());
   }
+
+  /* legend */
+  if (applyLegendSettingsToAll->isChecked()) {
+    i_plot = plot_min = 0;
+    plot_max = KST::plotList.count() - 1;
+  } else {
+    plot_min = plot_max = i_plot = Select->currentItem();
+  }
+
+  strLayout = LegendPosition->currentText();
+  for( i=0; i<iNumLegendLayouts; i++) {
+    if( strLayout.compare( LegendLayouts[i].Label ) == 0 ) {
+      layout = LegendLayouts[i].type;
+      break;
+    }
+  }
+
+  strAlignment = LegendAlignment->currentText();
+  for( i=0; i<iNumLegendAlignments; i++) {
+    if( strAlignment.compare( LegendAlignments[i].Label ) == 0 ) {
+      alignment = LegendAlignments[i].type;
+      break;
+    }
+  }
+
+  for (i_plot = plot_min; i_plot <= plot_max; i_plot++) {
+    plot = KST::plotList.at(i_plot);
+
+    plot->Legend->setFontName(LegendFontComboBox->currentText());
+    plot->Legend->setSize(LegendFontSize->value());
+    plot->Legend->setShow(ShowLegend->isChecked());
+    plot->Legend->setLayout(layout);
+    plot->Legend->setAlignment(alignment);
+    plot->Legend->setFront(legendInFront->isChecked());
+    plot->Legend->setColorForeground(legendColors->foreground());
+    plot->Legend->setColorBackground(legendColors->background());
+  }
 }
 
 void KstPlotDialogI::applyLimits(KstPlot *plot) {
@@ -376,15 +503,15 @@ void KstPlotDialogI::new_I() {
 
   applyLimits(plot);
 
-  plot->setForegroundColor(Colors->foreground());
-  plot->setBackgroundColor(Colors->background());
+//   plot->setForegroundColor(Colors->foreground());
+//   plot->setBackgroundColor(Colors->background());
 
   update();
 
   changePosition(PlotPosition->value());
 
   KST::plotList.arrangePlots(PlotCols->value());
-  doc->setDelay(UpdateDelay->value());
+  //doc->setDelay(UpdateDelay->value());
 
   update();
   emit docChanged();
@@ -417,19 +544,19 @@ void KstPlotDialogI::edit_I() {
     applyLabels(plot);
     applyLimits(plot);
 
-    if (ApplyToAll->isChecked()) {
-      for (unsigned i = 0; i < KST::plotList.count(); i++) {
-        KST::plotList.at(i)->setForegroundColor(Colors->foreground());
-        KST::plotList.at(i)->setBackgroundColor(Colors->background());
-      }
-    } else {
-      plot->setForegroundColor(Colors->foreground());
-      plot->setBackgroundColor(Colors->background());
-    }
+//     if (ApplyToAll->isChecked()) {
+//       for (unsigned i = 0; i < KST::plotList.count(); i++) {
+//         KST::plotList.at(i)->setForegroundColor(Colors->foreground());
+//         KST::plotList.at(i)->setBackgroundColor(Colors->background());
+//       }
+//     } else {
+//       plot->setForegroundColor(Colors->foreground());
+//       plot->setBackgroundColor(Colors->background());
+//     }
     changePosition(PlotPosition->value());
 
     KST::plotList.arrangePlots(PlotCols->value());
-    doc->setDelay(UpdateDelay->value());
+    //doc->setDelay(UpdateDelay->value());
 
     update();
     emit docChanged();
@@ -455,8 +582,8 @@ void KstPlotDialogI::updateSampNumLabel() {
     QPixmap pix(SampleNumLabel->size());
     QPainter p(&pix);
 
-    p.fillRect(p.window(), Colors->background());
-    p.setPen(Colors->foreground());
+    p.fillRect(p.window(), KstSettings::globalSettings()->backgroundColor);
+    p.setPen(KstSettings::globalSettings()->foregroundColor);
 
     SampleLabel->setFontName(FontComboBox->currentText());
     SampleLabel->setSize(NumberFontSize->value());
@@ -479,8 +606,8 @@ void KstPlotDialogI::updateSampTopLabel() {
     QPixmap pix(SampleTopLabel->size());
     QPainter p(&pix);
 
-    p.fillRect(p.window(), Colors->background());
-    p.setPen(Colors->foreground());
+    p.fillRect(p.window(), KstSettings::globalSettings()->backgroundColor);
+    p.setPen(KstSettings::globalSettings()->foregroundColor);
 
     SampleLabel->setFontName(FontComboBox->currentText());
     SampleLabel->setSize(TopLabelFontSize->value());
@@ -500,8 +627,8 @@ void KstPlotDialogI::updateSampXLabel() {
     QPixmap pix(SampleXLabel->size());
     QPainter p(&pix);
 
-    p.fillRect(p.window(), Colors->background());
-    p.setPen(Colors->foreground());
+    p.fillRect(p.window(), KstSettings::globalSettings()->backgroundColor);
+    p.setPen(KstSettings::globalSettings()->foregroundColor);
 
     SampleLabel->setFontName(FontComboBox->currentText());
     SampleLabel->setSize(XLabelFontSize->value());
@@ -521,8 +648,8 @@ void KstPlotDialogI::updateSampYLabel() {
     QPixmap pix(SampleYLabel->size());
     QPainter p(&pix);
 
-    p.fillRect(p.window(), Colors->background());
-    p.setPen(Colors->foreground());
+    p.fillRect(p.window(), KstSettings::globalSettings()->backgroundColor);
+    p.setPen(KstSettings::globalSettings()->foregroundColor);
 
     SampleLabel->setFontName(FontComboBox->currentText());
     SampleLabel->setSize(YLabelFontSize->value());
@@ -544,6 +671,34 @@ void KstPlotDialogI::updateLabels() {
   updateSampNumLabel();
 }
 
+void KstPlotDialogI::updateSampLegendLabel() {
+  if (LegendFontComboBox->currentText() != 0) {
+    QPixmap pix(SampleLegendLabel->size());
+    QPainter p(&pix);
+
+    p.fillRect(p.window(), KstSettings::globalSettings()->backgroundColor);
+    p.setPen(KstSettings::globalSettings()->foregroundColor);
+    if (legendInFront->isChecked()) {
+      p.fillRect(p.window(), legendColors->background());
+      p.setPen(legendColors->foreground());
+    } else {
+      p.fillRect(p.window(), KstSettings::globalSettings()->backgroundColor);
+      p.setPen(KstSettings::globalSettings()->foregroundColor);
+    }
+
+    SampleLabel->setFontName(LegendFontComboBox->currentText());
+    SampleLabel->setSize(LegendFontSize->value());
+    SampleLabel->setText(i18n("Curve name"));
+    SampleLabel->draw(p,SampleXLabel->width()/2,
+                      SampleXLabel->height()/2,true);
+
+    SampleLegendLabel->setPixmap(pix);
+  } else {
+    QFont font;
+    SampleLegendLabel->setFont(font);
+  }
+}
+
 void KstPlotDialogI::removeDisplayedCurve(){
   int i_curve = DisplayedCurveList->currentItem();
   if (i_curve >= 0) {
@@ -588,3 +743,4 @@ void KstPlotDialogI::updateButtons() {
 }
 
 #include "kstplotdialog_i.moc"
+// vim: et ts=2 sw=2
