@@ -43,18 +43,17 @@ public:
   virtual bool slaveVectorsUsed() const;
   bool isValid() const;
 
-  bool setPlugin(KSharedPtr<Plugin> plugin);
+  virtual bool setPlugin(KSharedPtr<Plugin> plugin);
   KSharedPtr<Plugin> plugin() const;
 
   virtual QString propertyString() const;
 
 protected:
   virtual void _showDialog();
+  KSharedPtr<Plugin> _plugin;
 
 private:
   void commonConstructor();
-
-  KSharedPtr<Plugin> _plugin;
   unsigned _inScalarCnt, _inArrayCnt, _outScalarCnt, _outArrayCnt;
 };
 
