@@ -109,14 +109,16 @@ void KstPluginDialogI::updatePluginList() {
   for (QMap<QString,Plugin::Data>::ConstIterator it = _pluginMap.begin();
                                                   it != _pluginMap.end();
                                                                      ++it) {
-    _pluginList += it.data()._name;
-    PluginCombo->insertItem(i18n("%1 (v%2) - %3").arg(it.data()._name)
-                                                 .arg(it.data()._version)
-                                                 .arg(it.data()._description));
-    if (it.data()._name == previous) {
-      newFocus = cnt;
+    if (it.data()._filter == false) {
+      _pluginList += it.data()._name;
+      PluginCombo->insertItem(i18n("%1 (v%2) - %3").arg(it.data()._name)
+                              .arg(it.data()._version)
+                              .arg(it.data()._description));
+      if (it.data()._name == previous) {
+        newFocus = cnt;
+      }
+      cnt++;
     }
-    cnt++;
   }
 
   if (newFocus != -1) {
@@ -137,9 +139,11 @@ void KstPluginDialogI::show_New() {
 
 
 void KstPluginDialogI::update(int new_index) {
+  QString selectedVector;
+  QString selectedScalar;
   int oldSelect = Select->currentItem();
   int oldCount = Select->count();
-
+  
   KstPluginList pl = kstObjectSubList<KstDataObject, KstPlugin>(KST::dataObjectList);
 
   Select->clear();
@@ -147,7 +151,7 @@ void KstPluginDialogI::update(int new_index) {
   for (KstPluginList::iterator it = pl.begin(); it != pl.end(); ++it) {
     Select->insertItem((*it)->tagName());
   }
-
+  
   if (new_index == -2 || Select->count() == 0) {
     Select->insertItem(i18n("P%1-%2").arg(Select->count()+1).arg(newPluginString));
     Select->setCurrentItem(Select->count()-1);
@@ -164,10 +168,10 @@ void KstPluginDialogI::update(int new_index) {
   }
 
   int oldPluginIndex = PluginCombo->currentItem();
-
   KstPluginPtr plugin = pl[Select->currentItem()];
-  if (plugin.data() && plugin->isValid()) {
-    int newPluginIndex = _pluginList.findIndex(plugin->plugin()->data()._name);
+  KSharedPtr<Plugin> pPtr = PluginCollection::self()->plugin(_pluginList[PluginCombo->currentItem()]);
+  if( pPtr != 0 ) {  
+    int newPluginIndex = _pluginList.findIndex(pPtr->data()._name);
     bool updateCombos = (newPluginIndex != oldPluginIndex);
 
     if (updateCombos) {
@@ -176,38 +180,61 @@ void KstPluginDialogI::update(int new_index) {
     }
 
     // Update input vector and scalar combos
-    const QValueList<Plugin::Data::IOValue>& itable = plugin->plugin()->data()._inputs;
+    const QValueList<Plugin::Data::IOValue>& itable = pPtr->data()._inputs;
     for (QValueList<Plugin::Data::IOValue>::ConstIterator it = itable.begin(); it != itable.end(); ++it) {
       if ((*it)._type == Plugin::Data::IOValue::TableType) { // vector
         QObject *field = _frameWidget->child((*it)._name.latin1(), "VectorSelector");
         assert(field);
-        VectorSelector *vs = static_cast<VectorSelector*>(field);
-        if (!updateCombos) {
-          vs->update();
+        if( field )
+        {
+          VectorSelector *vs = static_cast<VectorSelector*>(field);
+          selectedVector = vs->selectedVector( );
+          if (!updateCombos) {
+            vs->update();
+          }
+          if (plugin.data() && plugin->isValid()) {
+            vs->setSelection(plugin->inputVectors()[(*it)._name]->tagName());
+          }
+          else {
+            vs->setSelection(selectedVector);
+          }
         }
-        vs->setSelection(plugin->inputVectors()[(*it)._name]->tagName());
       } else {
         QObject *field = _frameWidget->child((*it)._name.latin1(), "ScalarSelector");
         assert(field);
-        ScalarSelector *ss = static_cast<ScalarSelector*>(field);
-        if (!updateCombos) {
-          ss->update();
+        if( field )
+        {
+          ScalarSelector *ss = static_cast<ScalarSelector*>(field);
+          selectedScalar = ss->selectedScalar( );
+          if (!updateCombos) {
+            ss->update();
+          }
+          if (plugin.data() && plugin->isValid()) {
+            ss->setSelection(plugin->inputScalars()[(*it)._name]->tagName());            
+          }
+          else {
+            ss->setSelection(selectedScalar);
+          }
         }
-        ss->setSelection(plugin->inputScalars()[(*it)._name]->tagName());
       }
     }
 
     // Update output vector and scalar lineedits
-    const QValueList<Plugin::Data::IOValue>& otable = plugin->plugin()->data()._outputs;
-    for (QValueList<Plugin::Data::IOValue>::ConstIterator it = otable.begin(); it != otable.end(); ++it) {
-      QObject *field = _frameWidget->child((*it)._name.latin1(), "QLineEdit");
-      assert(field);
-
-      QLineEdit *li = static_cast<QLineEdit*>(field);
-      if ((*it)._type == Plugin::Data::IOValue::TableType) { // vector
-        li->setText(plugin->outputVectors()[(*it)._name]->tagName());
-      } else { // scalar
-        li->setText(plugin->outputScalars()[(*it)._name]->tagName());
+    //    const QValueList<Plugin::Data::IOValue>& otable = plugin->plugin()->data()._outputs;
+    if (plugin.data() && plugin->isValid()) {
+      const QValueList<Plugin::Data::IOValue>& otable = pPtr->data()._outputs;
+      for (QValueList<Plugin::Data::IOValue>::ConstIterator it = otable.begin(); it != otable.end(); ++it) {
+        QObject *field = _frameWidget->child((*it)._name.latin1(), "QLineEdit");
+        assert(field);
+        if( field )
+        {
+          QLineEdit *li = static_cast<QLineEdit*>(field);
+          if ((*it)._type == Plugin::Data::IOValue::TableType) { // vector
+            li->setText(plugin->outputVectors()[(*it)._name]->tagName());
+          } else { // scalar
+            li->setText(plugin->outputScalars()[(*it)._name]->tagName());
+          }
+        }
       }
     }
   } else { // invalid plugin
@@ -297,28 +324,30 @@ void KstPluginDialogI::new_I() {
   int pitem = PluginCombo->currentItem();
   if (pitem >= 0 && PluginCombo->count() > 0) {
     KSharedPtr<Plugin> pPtr = PluginCollection::self()->plugin(_pluginList[pitem]);
-    plugin = new KstPlugin;
-    if (!saveInputs(plugin, pPtr)) {
-      return;
-    }
+    if (pPtr != 0L) {
+      plugin = new KstPlugin;
+      if (!saveInputs(plugin, pPtr)) {
+        return;
+      }
 
-    plugin->setPlugin(pPtr);
+      plugin->setPlugin(pPtr);
 
-    if (!saveOutputs(plugin, pPtr)) {
-      return;
-    }
+      if (!saveOutputs(plugin, pPtr)) {
+        return;
+      }
 
-    if (tagName.endsWith(newPluginString)) {
-      QString tmpTagName;
-      int i = 0;
-      do {
-        tmpTagName = i18n("P%1-%2").arg(++i).arg(_pluginList[pitem]);
-      } while (KST::dataTagNameNotUnique(tmpTagName, false));
-      tagName = tmpTagName;
+      if (tagName.endsWith(newPluginString)) {
+        QString tmpTagName;
+        int i = 0;
+        do {
+          tmpTagName = i18n("P%1-%2").arg(++i).arg(_pluginList[pitem]);
+        } while (KST::dataTagNameNotUnique(tmpTagName, false));
+        tagName = tmpTagName;
+      }
+      plugin->setTagName(tagName);
     }
-    plugin->setTagName(tagName);
   }
-
+  
   if (!plugin || !plugin->isValid()) {
     KMessageBox::sorry(0L, i18n("There is an error in the plugin you entered. Please fix it."));
     return;
