@@ -15,20 +15,22 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#include <qwidget.h>
-#include <qstring.h>
+#include <qcheckbox.h>
+#include <qcombobox.h>
+#include <qlabel.h>
+#include <qlineedit.h>
 #include <qlistbox.h>
 #include <qpushbutton.h>
-#include <qcombobox.h>
-#include <qlineedit.h>
-#include <qcheckbox.h>
-#include <qspinbox.h>
-#include <qlabel.h>
 #include <qradiobutton.h>
+#include <qspinbox.h>
+#include <qstring.h>
+#include <qwidget.h>
+
+#include <kcolordialog.h>
 #include <kfiledialog.h>
 #include <klocale.h>
-#include <kcolordialog.h>
 #include <kmessagebox.h>
+#include <kstsettings.h>
 #include <kurlrequester.h>
 
 #include "kstplotlist.h"
@@ -37,12 +39,11 @@
 #include "kstdatacollection.h"
 
 #include "kstquickpsddialog_i.h"
+#include "curveappearancewidget.h"
 
 KstQuickPSDDialogI::KstQuickPSDDialogI(QWidget* parent, const char* name,
                                            bool modal, WFlags fl)
 : KstQuickPSDDialog(parent, name, modal, fl) {
-
-    connect(ColorChange, SIGNAL(clicked()), this, SLOT(changeColor()));
     connect(Apply, SIGNAL(clicked()), this, SLOT(apply()));
     connect(ApplyPlotCols, SIGNAL(clicked()), this, SLOT(addPlot()));
     connect(SourceVector, SIGNAL(stateChanged(int)),
@@ -50,6 +51,8 @@ KstQuickPSDDialogI::KstQuickPSDDialogI(QWidget* parent, const char* name,
 
     FileName->setMode(KFile::File | KFile::Directory | KFile::ExistingOnly
                       | KFile::LocalOnly);
+    
+    DataFileEntry->setEnabled(false);
 }
 
 KstQuickPSDDialogI::~KstQuickPSDDialogI() {
@@ -104,7 +107,6 @@ void KstQuickPSDDialogI::update() {
     Skip->setValue(v0->skip());
     DoSkip->setChecked(v0->doSkip());
     DoFilter->setChecked(v0->doAve());
-    DataFileEntry->setEnabled(false);
   } else {
     SourceVector->setChecked(false);
     SourceVector->setEnabled(false);
@@ -124,9 +126,9 @@ void KstQuickPSDDialogI::update() {
 
   PlotCols->setValue(KST::plotList.getPlotCols());
 
-  /* set the color and draw the line */
-  setCurveColor(KstColorSequence::next());
-  drawCurveLine();
+  /* set the color*/
+  _curveAppearance->setColor(KstColorSequence::next());
+  setCurveColor( _curveAppearance->color() );
 }
 
 void KstQuickPSDDialogI::setCurveColor(const QColor &c) {
@@ -138,27 +140,13 @@ QColor KstQuickPSDDialogI::curveColor() {
   return CurveColor;
 }
 
-
-void KstQuickPSDDialogI::drawCurveLine() {
-  QPixmap pix(CurveAppearanceLabel->size());
-  QPainter p(&pix);
-  KstPoint tmppoint;
-
-  p.fillRect(p.window(), QColor("white"));
-  p.setPen(curveColor());
-
-  p.drawLine(1,pix.height()/2,pix.width()-1, pix.height()/2);
-  CurveAppearanceLabel->setPixmap(pix);
-}
-
-
 void KstQuickPSDDialogI::changeColor() {
   QColor c;
   c = curveColor();
   if ((int)KColorDialog::getColor(c) == (int)KColorDialog::Accepted ) {
     setCurveColor(c);
   }
-  drawCurveLine();
+  _curveAppearance->setColor(c);
 }
 
 void KstQuickPSDDialogI::apply(bool autolabel) {
@@ -279,7 +267,10 @@ void KstQuickPSDDialogI::apply(bool autolabel) {
   /* create the psd curve */
   curve = new KstPSDCurve(c_name, vx, new_freq, new_len,
                         PSDVectorUnits->text(), PSDRateUnits->text(),
-                        curveColor());
+                        _curveAppearance->color());
+  curve->setHasPoints(_curveAppearance->showPoints());
+  curve->setHasLines(_curveAppearance->showLines());
+  curve->Point.setType(_curveAppearance->pointType());
 
   KST::dataObjectList.append(curve.data());
   /* assign curve to plot */
