@@ -94,8 +94,7 @@ KstRVector::KstRVector(QDomElement &e, const QString &o_file,
     }
   }
   /* Call the common constructor */
-  commonRVConstructor(in_file, in_field, in_f0, in_n, in_skip,
-		      in_DoSkip, in_DoAve);
+  commonRVConstructor(in_file, in_field, in_f0, in_n, in_skip, in_DoSkip, in_DoAve);
 }
 
 void KstRVector::commonRVConstructor(KstDataSourcePtr in_file,
@@ -129,7 +128,9 @@ void KstRVector::commonRVConstructor(KstDataSourcePtr in_file,
     ReqF0 = 0;
   }
 
-  SPF = _file->samplesPerFrame(Field);
+  if (_file) {
+    SPF = _file->samplesPerFrame(Field);
+  }
 
   _dirty = true;
 
@@ -245,6 +246,10 @@ int KstRVector::reqStartFrame() const {
 
 /** Save vector information */
 void KstRVector::save(QTextStream &ts) {
+  if (!_file) {
+    return;
+  }
+
   ts << "  <tag>" << _tag << "</tag>" << endl;
   ts << "  <filename>" << _file->fileName() << "</filename>" << endl;
   ts << "  <field>" << Field << "</field>" << endl;
@@ -260,7 +265,7 @@ void KstRVector::save(QTextStream &ts) {
 
 /** return the name of the file */
 QString KstRVector::filename() const {
-  return _file->fileName();
+  return _file ? _file->fileName() : QString::null;
 }
 
 /** return the field */
@@ -273,7 +278,7 @@ QString KstRVector::label() const {
   QString label;
 
   Field.toInt(&ok);
-  if (ok && _file->fileType() == "ASCII") {
+  if (ok && _file && _file->fileType() == "ASCII") {
     label = i18n("Column %1").arg(Field);
   } else {
     label = Field;
@@ -283,7 +288,7 @@ QString KstRVector::label() const {
 }
 
 void KstRVector::reset() {
-  SPF = _file->samplesPerFrame(Field);
+  SPF = _file ? _file->samplesPerFrame(Field) : SPF;
   F0 = NF = 0;
   resize(0);
   _numSamples = 0;
@@ -301,7 +306,7 @@ void KstRVector::checkIntegrity() {
   }
 
   /* if it looks like we have a new file, reset */
-  if (SPF != _file->samplesPerFrame(Field.latin1()) || _file->frameCount() < NF) {
+  if (_file && (SPF != _file->samplesPerFrame(Field.latin1()) || _file->frameCount() < NF)) {
     reset();
   }
 
@@ -335,6 +340,10 @@ KstObject::UpdateType KstRVector::doUpdate(bool force) {
 
   checkIntegrity();
 
+  if (!_file) {
+    return NO_CHANGE;
+  }
+
   /*******************************/
   /**** Set new_nf and new_f0 ****/
   // ReqNF <=0 means read from ReqF0 to end of File
@@ -407,22 +416,22 @@ KstObject::UpdateType KstRVector::doUpdate(bool force) {
     /** read each sample from the File */
     for (i = NF, j = 0; i < new_nf; i += Skip, j++) {
       if (DoAve) {
-	/* enlarge AveReadBuf if necessary */
-	if (N_AveReadBuf < Skip*SPF) {
-	  N_AveReadBuf = Skip*SPF;
-	  AveReadBuf = static_cast<double*>
-                       (realloc(AveReadBuf, N_AveReadBuf*sizeof(double)));
-	}
-	ave_nread = _file->readField(AveReadBuf, Field, new_f0+i, Skip);
-	for (k = 1; k < ave_nread; k++) {
+        /* enlarge AveReadBuf if necessary */
+        if (N_AveReadBuf < Skip*SPF) {
+          N_AveReadBuf = Skip*SPF;
+          AveReadBuf = static_cast<double*>
+            (realloc(AveReadBuf, N_AveReadBuf*sizeof(double)));
+        }
+        ave_nread = _file->readField(AveReadBuf, Field, new_f0+i, Skip);
+        for (k = 1; k < ave_nread; k++) {
           AveReadBuf[0] += AveReadBuf[k];
         }
-	if (ave_nread > 0) {
-	  _v[_numSamples + j] = AveReadBuf[0]/double(ave_nread);
-	  n_read++;
-	}
+        if (ave_nread > 0) {
+          _v[_numSamples + j] = AveReadBuf[0]/double(ave_nread);
+          n_read++;
+        }
       } else {
-	n_read += _file->readField(_v + _numSamples + j, Field, new_f0 + i, -1);
+        n_read += _file->readField(_v + _numSamples + j, Field, new_f0 + i, -1);
       }
     }
   } else {
@@ -486,6 +495,10 @@ int KstRVector::fileLength() const {
 }
 
 void KstRVector::reload() {
+  if (!_file) {
+    return;
+  }
+
   // FIXME: inefficient
   KstDataSourcePtr newsrc = KstDataSource::loadSource(_file->fileName(), _file->fileType());
   if (newsrc) {
