@@ -24,7 +24,7 @@
 KstScalar::KstScalar(const QString& in_tag, double val) : KstObject() {
   _tag = in_tag;
   if (_tag.isEmpty()) {
-    QString nt = "Anonymous Scalar %1";
+    QString nt = i18n("Anonymous Scalar %1");
     int i = 0;
     // FIXME: make me more efficient
     do {
@@ -39,9 +39,11 @@ KstScalar::KstScalar(const QString& in_tag, double val) : KstObject() {
   KST::scalarList.append(this);
 }
 
+
 KstScalar::~KstScalar() {
 }
 
+
 KstObject::UpdateType KstScalar::update(int updateCounter) {
   Q_UNUSED(updateCounter);
 return NO_CHANGE;
@@ -52,9 +54,16 @@ void KstScalar::save(QTextStream &ts) {
   Q_UNUSED(ts);
 }
 
+
 KstScalar& KstScalar::operator=(double v) {
   _value = v;
 return *this;
 }
 
 
+bool KstScalar::isGlobal() const {
+  // can't use find() due to constness issues
+  return KST::scalarList.findTag(tagName()) != KST::scalarList.end();
+}
+
+// vim: et ts=2 sw=2
