@@ -42,8 +42,8 @@ static KCmdLineOptions options[] = {
   { "y <Y>",  I18N_NOOP("Field for Y axis (multiple allowed)"), 0 },
   { "ye <equation>",  I18N_NOOP("Equation for Y axis (multiple allowed)"), 0 },
   { "e <E>",  I18N_NOOP("Field for Y errors (multiple allowed)"), 0 },
-  { "x <X>",  I18N_NOOP("Field for X axis"),                 "INDEX"},
-  { "xe <equation>",  I18N_NOOP("Equation for X axis"),      "<none>"},
+  { "x <X>",  I18N_NOOP("Field or range for X axis"),        "INDEX"},
+  { "xe <X>", I18N_NOOP("X vector for equations x0:x1:n"),   "INDEX"},
   { "p <Y>",  I18N_NOOP("Field for power spectrum (multiple allowed)"), 0},
   { "h <Y>",  I18N_NOOP("Field for histogram (multiple allowed)"), 0},
   { "r <f>",  I18N_NOOP("Sample rate for power spectrum"),      "60.0"},
@@ -56,6 +56,7 @@ static KCmdLineOptions options[] = {
   { "a",      I18N_NOOP("Apply boxcar filter before skipping frames"),0},
   { "m <NC>", I18N_NOOP("Separate plots arranged in <NC> columns"),0},
   { "d",      I18N_NOOP("Display as points rather than curves"),0},
+  { "g",      I18N_NOOP("Provide a legend box"),0},
   { "print <file>",  I18N_NOOP("Print to file and exit"),"<none>"},
   { "png <file>",  I18N_NOOP("Save as a png file and exit"),"<none>"},
   { "+[Files]", I18N_NOOP("Data files (if -y given) or *.kst file"), 0},
@@ -66,6 +67,7 @@ struct InType {
   int skip;
   bool doskip;
   bool doave;
+  bool dolegend;
   int n;
   int f;
   double rate;
@@ -122,13 +124,19 @@ void SetCMDOptions(KCmdLineArgs *args, struct InType &in,
   in.has_points = args->isSet("d");
   in.n_cols = args->getOption("m").toInt(&nOK);
   if (in.n_cols>0) {
-    in.sep_plots = true;
-    in.n_plots = args->count() * (n_y);
+    if (args->count()>0) {
+      in.sep_plots = true;
+      in.n_plots = args->count() * (n_y);
+    } else if (args->getOptionList("ye").count()>0) {
+      in.sep_plots = true;
+      in.n_plots = args->getOptionList("ye").count();
+    }
   } else {
     in.n_cols = 1;
     in.n_plots = 1;
     in.sep_plots = false;
   }
+
   in.n_rows = (in.n_plots-1)/in.n_cols + 1;
 
   /* set skip options */
@@ -145,6 +153,7 @@ void SetCMDOptions(KCmdLineArgs *args, struct InType &in,
   /* set Units for PSDs */
   in.VUnits = args->getOption("yu");
   in.RUnits = args->getOption("ru");
+  in.dolegend = args->isSet("g");
 }
 
 /****************************************************************/
@@ -170,50 +179,99 @@ void CreatePlots(struct InType &in) {
   }
 }
 
-/****************************************************************/
-/*                                                              */
-/*        create vectors, including name and error cheking      */
-/*                                                              */
-/****************************************************************/
-KstRVectorPtr CreateVector(QString field, KstDataSourcePtr file, struct InType &in) {
-  KstRVectorPtr vector;
-  static int i_v = 0;
+/******************************************************************/
+/*                                                                */
+/*        set X range for equations if -xe is specified           */
+/*        start:end:Nsamp                                         */
+/*                                                                */
+/******************************************************************/
+void SetEqXRanges(QString xeqS, double *min, double *max, int *n, bool *ok) {
+  *ok = true;
+  QStringList fields = QStringList::split( QChar(':'), xeqS );
+  if (fields.count()!=3) {
+    *ok=false;
+    *n=2;
+    *min = -1;
+    *max = 1;
+    return;
+  }
+  QString f;
+  f = *fields.at(0);
+  *min = f.toDouble(ok);
+  f = *fields.at(1);
+  *max = f.toDouble(ok);
+  f = *fields.at(2);
+  *n = f.toInt(ok);
 
-  vector = new KstRVector(file, field, 
+  if (*n<2) *ok=false;
+  if (*min>=*max) *ok = false;
+}
+
+/******************************************************************/
+/*                                                                */
+/*        create vectors, including name and error checking       */
+/*        if a vector with the same field and file exists, use it */
+/*                                                                */
+/******************************************************************/
+KstRVector *GetOrCreateVector(QString field, KstDataSourcePtr file, struct InType &in) {
+  int i_v = 0, n_v;
+  KstRVector *V;
+  KstRVectorList vectorList =
+    kstObjectSubList<KstVector,KstRVector>(KST::vectorList);
+
+  n_v = vectorList.count();
+
+  for (i_v=0; i_v<n_v; i_v++) {
+    V = *vectorList.at(i_v);
+    if (V->getField() == field) {
+      if (V->filename() == file->fileName()) {
+	return (V);
+      }
+    }
+  }
+  V = new KstRVector(file, field,
 			  QString("V") + QString::number(1 + i_v++)
                           + "-" + field,
                           in.f, in.n, in.skip, in.doskip, in.doave);
-  if (!vector->isValid()) {
-    kdError() << I18N_NOOP("Error: Invalid field: ") << vector->getField()
-              << endl << I18N_NOOP("File: ") << vector->filename() << endl;
+  if (!V->isValid()) {
+    kdError() << I18N_NOOP("Error: Invalid field: ") << V->getField()
+              << endl << I18N_NOOP("File: ") << V->filename() << endl;
     exit(0); // fixme: this can cause crashes
   }
 
-  return vector;
+  return V;
 }
 
 /****************************************************************/
 /*                                                              */
 /*        Process Equation: replace fields with vector tags     */
+/*        Create vectors that don't exist.                      */
 /*                                                              */
 /****************************************************************/
-// void ProcessEq(QString &eq) {
-//   QString field;
-//   int i0=0, i1=0;
-//   KstVectorPtr v;
-//   int i_vector;
+bool NoVectorEq(QString eq) {
+  if (eq.find("[")>=0)
+    return false;
+  else
+    return true;
+}
 
-//   while ((i0 = eq.find("[", i0))>=0) {
-//     i1 = eq.find("]", i0);
-//     if (i1>0) {
-//       field = eq.mid(i0+1, i1-i0-1);
-//       for (i_vector = 0; i_vector<KST::vectorList.count(); i_vector++);
-//       }
-//       eq.replace(i0,i1-i0+1, "[V_"+field+"]");
-//     }
-//     i0++;
-//   }
-// }
+void ProcessEq(QString &eq, KstDataSourcePtr file,
+               struct InType &in, bool *ok) {
+  QString field;
+  int i0=0, i1=0;
+  KstVector *v;
+  *ok = true;
+
+  while ((i0 = eq.find("[", i0))>=0) {
+    i1 = eq.find("]", i0);
+    if (i1>0) {
+      field = eq.mid(i0+1, i1-i0-1);
+      v = GetOrCreateVector(field, file, in);
+      eq.replace(i0,i1-i0+1, "["+v->tagName()+"]");
+    }
+    i0++;
+  }
+}
 
 /****************************************************************/
 /*                                                              */
@@ -225,7 +283,7 @@ int main(int argc, char *argv[]) {
   int i_plot;
 
   KAboutData aboutData( "kst", I18N_NOOP("Kst"),
-                        "0.94", description, KAboutData::License_GPL,
+                        "0.95", description, KAboutData::License_GPL,
                         I18N_NOOP("(c) 2000-2003 Barth Netterfield"),
                         0,
                         "http://extragear.kde.org/apps/kst.php");
@@ -252,26 +310,27 @@ int main(int argc, char *argv[]) {
     struct InType in;
     QColor color;
     QCStringList ycolList;
-    // QCStringList yEqList;
+    QCStringList yEqList;
     QCStringList psdList;
     QCStringList hsList;
     QCStringList errorList;
     unsigned int i_ycol;
     QCStringList::Iterator psd;
     QCStringList::Iterator hs;
-    //QCStringList::Iterator eq_i;
+    QCStringList::Iterator eq_i;
     bool nOK;
 
     /* temp variables: these all get stuck into list objects */
     KstDataSourcePtr file;
-    KstRVectorPtr xvector;
-    KstRVectorPtr yvector;
-    KstRVectorPtr evector;
+    KstRVector *xvector=NULL;
+    KstRVector *yvector;
+    KstRVector *evector;
     KstVCurve *curve;
     KstPSDCurve *psdcurve;
-    KstHistogramPtr hscurve;
+    KstEquationCurve *eqcurve;
+    KstHistogram *hscurve;
     KstPlot *plot;
-    int n_y;
+    int n_y, n_eq=0;
 
     /* Parse command line args */
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
@@ -283,13 +342,14 @@ int main(int argc, char *argv[]) {
 
     /* get Y axis collums */
     ycolList = args->getOptionList("y");
-    //yEqList = args->getOptionList("ye");
+    yEqList = args->getOptionList("ye");
     psdList = args->getOptionList("p");
     hsList = args->getOptionList("h");
     errorList = args->getOptionList("e");
+
     // y axis or PSD specified, so the files are data files, not kst files.
-    n_y = ycolList.count() + psdList.count() + hsList.count();
-    //+ yEqList.count();
+    n_y = ycolList.count() + psdList.count() + hsList.count()
+      + yEqList.count();
     if (n_y > 0) {
 
       SetCMDOptions(args, in, n_y);
@@ -299,21 +359,54 @@ int main(int argc, char *argv[]) {
       i_plot = 0;
       plot = KST::plotList.at(i_plot);
 
+      /* make stand alone equations if there are no files */
+      if (args->count()<1) {
+        if (!yEqList.isEmpty()) {
+	  QString eqS;
+          double max, min;
+          int n;
+          bool xeq;
+          SetEqXRanges(args->getOption("xe"), &min, &max, &n, &xeq);
+          if (xeq) {
+            for (eq_i = yEqList.begin(); eq_i != yEqList.end(); ++eq_i) {
+              eqS = *eq_i;
+              if (NoVectorEq(eqS)) {
+                eqcurve =
+                  new KstEquationCurve(QString("E")+QString::number(n_eq+1)+
+                                       "-" + eqS,
+                                       eqS,
+                                       min,max,n, KstColorSequence::next());
+
+                KST::dataObjectList.append(eqcurve);
+                plot->addCurve(eqcurve);
+
+                if (in.sep_plots) {
+                  i_plot++;
+                  if (i_plot <in.n_plots) plot = KST::plotList.at(i_plot);
+                }
+              }
+            }
+          }
+        }
+      }
+
       /* Make the requested curves for each data file */
       for (i_curve = i_v = 0, i_file = 0; i_file < args->count(); i_file++) {
         /* Make the file */
         file = KstDataSource::loadSource(args->arg(i_file));
 
         if (!file) {
-          kdWarning() << I18N_NOOP("Error: No data in file: ")
-	              << args->arg(i_file) << endl;
+          std::cerr << I18N_NOOP("Error: No data in file: ")
+	       << args->arg(i_file) << "\n";
           delete kst;
           exit(0);
         }
 
 	if (!file->isValid() || file->frameCount() < 1) {
-          kdWarning() << I18N_NOOP("Error: No data in file: ")
-	              << args->arg(i_file) << endl;
+          std::cerr << I18N_NOOP("No data in file: ")
+	       << args->arg(i_file)
+	       << ".  Trying to continue..."
+	       << "\n";
           // The file might get data later!
 	}
 
@@ -321,11 +414,11 @@ int main(int argc, char *argv[]) {
 
         if (!ycolList.isEmpty()) { // if there are some xy plots
           /* make the x axis vector */
-          xvector = CreateVector(args->getOption("x"), file, in);
+          xvector = GetOrCreateVector(args->getOption("x"), file, in);
 
           /* make the y axis vectors */
           for (i_ycol = 0; i_ycol < ycolList.count(); ++i_ycol ) {
-            yvector = CreateVector(*(ycolList.at(i_ycol)), file, in);
+            yvector = GetOrCreateVector(*(ycolList.at(i_ycol)), file, in);
 
             /* make the curves */
             color = KstColorSequence::next();
@@ -339,7 +432,7 @@ int main(int argc, char *argv[]) {
             }
 
             if (i_ycol<errorList.count()) {
-              evector = CreateVector(*(errorList.at(i_ycol)), file, in);
+              evector = GetOrCreateVector(*(errorList.at(i_ycol)), file, in);
               curve->setYError(KstVectorPtr(evector));
             }
             KST::dataObjectList.append(curve);
@@ -352,27 +445,46 @@ int main(int argc, char *argv[]) {
             } // end (if they are separate plots)
           } // next y col
         } // end (if there are some xy plots)
-// 	if (!yEqList.isEmpty()) {
-// 	  QString eq;
-// 	  for (eq_i = yEqList.begin(); eq_i != yEqList.end(); ++eq_i) {	  
-// 	    eq = *eq_i;
-// 	    ProcessEq(eq);
-// 	  }
-// 	}
+	if (!yEqList.isEmpty()) {
+	  QString eqS;
+          double max, min;
+          int n;
+          bool xeq, eq_ok;
+
+          SetEqXRanges(args->getOption("xe"), &min, &max, &n, &xeq);
+	  for (eq_i = yEqList.begin(); eq_i != yEqList.end(); ++eq_i) {
+	    eqS = *eq_i;
+	    ProcessEq(eqS, file, in, &eq_ok);
+            if (xeq) {
+              eqcurve =
+                new KstEquationCurve(QString("E")+QString::number(n_eq+1)+
+                                     "-" + eqS,
+                                     eqS,
+                                     min,max,n, KstColorSequence::next());
+            } else {
+              if (xvector==NULL)
+                xvector = GetOrCreateVector(args->getOption("x"), file, in);
+
+              eqcurve =
+                new KstEquationCurve(QString("E")+QString::number(n_eq+1)+eqS,
+                                     eqS,
+                                     KstVectorPtr(xvector),
+                                     true, KstColorSequence::next());
+            }
+            KST::dataObjectList.append(eqcurve);
+            plot->addCurve(eqcurve);
+
+            if (in.sep_plots) {
+              i_plot++;
+              if (i_plot <in.n_plots) plot = KST::plotList.at(i_plot);
+            }
+	  }
+	}
         if (psdList.count() > 0) { // if there are some psd plots
           KstRVectorList rvl = kstObjectSubList<KstVector,KstRVector>(KST::vectorList);
           for(psd = psdList.begin(); psd != psdList.end(); ++psd ) {
-            KstRVectorList::Iterator it;
-            for (it = rvl.begin(); it != rvl.end(); ++it) {
-              if ((*it)->getField() == (*psd).data()) {
-                break;
-              }
-            }
-            if (it != rvl.end()) {
-              yvector = *it;
-            } else {
-              yvector = CreateVector(*psd, file, in);
-            } // end (if the vector hasn't yet been created)
+
+	    yvector = GetOrCreateVector(*psd, file, in);
 
             color = KstColorSequence::next();
 
@@ -396,48 +508,16 @@ int main(int argc, char *argv[]) {
           } // next psd
         } // end (if there are some psds)
         if (hsList.count()>0) { // if there are some histograms
-          double max, min, m;
+          double max, min;
           int N;
 
           KstRVectorList rvl = kstObjectSubList<KstVector,KstRVector>(KST::vectorList);
           for (hs = hsList.begin(); hs != hsList.end(); ++hs ) {
-            KstRVectorList::Iterator it;
-            for (it = rvl.begin(); it != rvl.end(); ++it) {
-              if ((*it)->getField() == (*hs).data()) {
-                break;
-              }
-            }
-            if (it != rvl.end()) {
-              yvector = *it;
-            } else {
-              yvector = CreateVector(*hs, file, in);
-            } // end (if the vector hasn't yet been created)
+	    yvector = GetOrCreateVector(*hs, file, in);
 
             color = KstColorSequence::next();
-            max = yvector->max();
-            min = yvector->min();
-            N = yvector->sampleCount();
 
-            if (max<min) {
-              m = max;
-              max = min;
-              min = m;
-            }
-            if (max==min) {
-              max+=1;
-              min -=1;
-            }
-
-            N /= 50;
-            if (N < 6) {
-              N = 6;
-            } else if (N > 60) {
-              N = 60;
-            }
-
-            m = (max -min)/(100.0*double(N));
-            max += m;
-            min -= m;
+            KstHistogram::AutoBin(KstVectorPtr(yvector), &N, &max, &min);
 
             hscurve = new KstHistogram(QString("H") +
                                        QString::number(1+i_curve++)
@@ -457,10 +537,14 @@ int main(int argc, char *argv[]) {
         } // end (if there are some histograms)
       } // next data file
       for (i_plot = 0; i_plot < in.n_plots; i_plot++) {
-        KST::plotList.at(i_plot)->GenerateDefaultLabels();
+        plot = KST::plotList.at(i_plot);
+        plot->GenerateDefaultLabels();
+        if (in.dolegend) {
+          plot->Legend->setShow(true);
+          plot->Legend->setFront(true);
+        }
       }
       KST::plotList.setPlotCols(in.n_cols);
-
     } else if (args->count() > 0) {
       /* open a kst file */
       /* some of the options can be overridden */
@@ -506,6 +590,7 @@ int main(int argc, char *argv[]) {
       app.setMainWidget(kst);
       kst->show();
     }
+
     // LEAVE THIS HERE - causes crashes otherwise!
     int rc = app.exec();
     delete kst;
